#
# spec file for package datamash
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# bypass https://bugzilla.opensuse.org/show_bug.cgi?id=1149348
%ifarch ppc64le ppc64 aarch64
%define _lto_cflags %{nil}
%endif

Name:           datamash
Version:        1.7
Release:        1.6
Summary:        Statistical, numerical and textual operations in the command line
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.gnu.org/software/datamash/
Source:         https://ftp.gnu.org/gnu/datamash/%{name}-%{version}.tar.gz
Source2:        https://ftp.gnu.org/gnu/datamash/%{name}-%{version}.tar.gz.sig
Source3:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=datamash&download=1#/%{name}.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
GNU datamash is a command-line program which performs basic numeric,
textual and statistical operations on input textual data files.

%prep
%setup -q

%build
%configure \
	--docdir=%{_docdir}/%{name} \
	--with-openssl=yes \
	--with-packager="%{vendor}" \
	--with-packager-version="%{distribution} %{version}-%{release}" \
	--with-packager-bug-reports="%{packager}" \
	--with-bash-completion-dir=no
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}

%check
make %{?_smp_mflags} check

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files -f %{name}.lang
%license COPYING
%doc ChangeLog README AUTHORS THANKS TODO
%{_bindir}/*
%{_mandir}/man1/*.1%{?ext_man}
%{_infodir}/%{name}.info%{?ext_info}
%{_datadir}/%{name}

%changelog
* Sat Apr 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.7:
  * decorate(1): new program - sorts input in non-standard ordering
    e.g. IPv4, IPv6, roman numerals.
  * New operations: sha224/sha384
  * New operations: geomean (Geometric mean) and harmmean (Harmonic
    mean)
- includes changes from 1.6:
  * The 'gutnum' operation now correctly prints detected numbers
    without truncating them
* Thu Sep 19 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.5:
  * accept backslash-escaped characters in field names
  * New operations for handling file names and paths
  * New getnum operation to extract a number from a string
  * New operation: cut, similar to cut(1)
* Wed Sep  4 2019 Michel Normand <normand@linux.vnet.ibm.com>
- disable LTO for ppc64 ppc64le aarch64 bypass boo#1149348
* Wed Dec 26 2018 astieger@suse.com
- update to 1.4:
  * New option: -C/--skip-comments to skip comment lines
- drop upsteamed patches:
  * upstream-disable-broken-test.patch
  * upstream-fix-test.patch
* Fri Mar 23 2018 guillaume.gardet@opensuse.org
- Disable broken test with upstream patch:
  * upstream-disable-broken-test.patch
- Fix another test
  * upstream-fix-test.patch
* Sat Mar 17 2018 astieger@suse.com
- initial package 1.3
